model AllostericControl "Example model showcasing how allosteric control works using the ATCase pathway."
  extends BioChem.Compartments.ConstantCompartment(V(start = 1.0), mainCompartment = false);
  parameter BioChem.Units.ReactionCoefficient kOn = 10 "Reaction rate for forward enzyme - substrate binding";
  parameter BioChem.Units.ReactionCoefficient kOff = 1 "Reaction rate for reverse enzyme - substrate binding";
  parameter BioChem.Units.ReactionCoefficient kCat = 1 "Reaction rate for enzyme catalyzed reaction";
  BioChem.Substances.Substance Phosphate(c.start = 0) "By-product from the reaction." annotation(Placement(visible = true, transformation(origin = {70, 7.132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance Carbamoyl_Aspartate(c.start = 0) "Intermediate reactant of the pyrimidine metabolism." annotation(Placement(visible = true, transformation(origin = {70, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance Carbamoyl_Phosphate(c.start = 10000) "Reactant that together with asparatate forms carbomyl asparatate. Here the concentration is high enough to not limit the reaction." annotation(Placement(visible = true, transformation(origin = {-30, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance CTP(c.start = 1) "Cytidine triphosphate, pushes ATCase towards its tense state." annotation(Placement(visible = true, transformation(origin = {-70, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Irreversible.UniUni.Uuifi finalStep "Final step of the pyrimidine metabolism, forms CTP (cytidine triphosphate)." annotation(Placement(visible = true, transformation(origin = {100, 30}, extent = {{-10, 10}, {10, -10}}, rotation = 360)));
  BioChem.Substances.Substance Aspartate(c.start = 10) "Main reactant, forming carbomyl aspartate when bound to ATCase and carbomyl phosphate." annotation(Placement(visible = true, transformation(origin = {-45, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance ATCase_T(c.start = 1) "Tense state of ATCase, almost no affinity for aspartate." annotation(Placement(visible = true, transformation(origin = {-90, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance ATCase_R(c.start = 0) "Relaxed state of ATCase, high affinity of aspartate." annotation(Placement(visible = true, transformation(origin = {-90, 51.534}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance ATP(c.start = 1) "Adenosine triphosphate, pushes ATCase towards its relaxed state." annotation(Placement(visible = true, transformation(origin = {-120, 15}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Reversible.TriUni.Tur enzymeSubstrateBidning(k1 = kOn, k2 = kOff) "Reversiable reaction that bind the substate together with a free enzyme, forming a complex." annotation(Placement(visible = true, transformation(origin = {-7.305, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance complex(c.start = 0) "ATCase, aspartate and carbomyl phosphat complex." annotation(Placement(visible = true, transformation(origin = {12.171, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Irreversible.UniTri.Uti enzymeReaction(k1 = kCat) "Reaction that forms the product and releases the enzyme from the binding." annotation(Placement(visible = true, transformation(origin = {35, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance UTP(c.start = 1) "Uridine triphosphate, pushes ATCase towards its tense state." annotation(Placement(visible = true, transformation(origin = {-130, 25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Reversible.UniUni.Uurfafiba conformationEquilibrium(nAFe = 3.5, nIFe = 5.5, nABe = 3.5, k2 = 20) "Equlibrium reaction under allosteric control, regulated by UTP, ATP and CTP." annotation(Placement(visible = true, transformation(origin = {-90, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
equation
  connect(enzymeReaction.p1, ATCase_R.n1) annotation(Line(visible = true, origin = {35.861, 50.984}, points = {{10.389, -15.984}, {10.389, 9.016}, {-128.404, 9.016}, {-125.861, 0.55}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(enzymeReaction.p2, Carbamoyl_Aspartate.n1) annotation(Line(visible = true, origin = {58.125, 30}, points = {{-11.875, 0}, {11.875, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(enzymeReaction.p3, Phosphate.n1) annotation(Line(visible = true, origin = {54.875, 11.599}, points = {{-8.625, 13.401}, {-8.625, -4.467}, {2.125, -4.467}, {15.125, -4.467}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(complex.n1, enzymeReaction.s1) annotation(Line(visible = true, origin = {16.031, 30}, points = {{-3.86, 0}, {-3.86, 0}, {7.719, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(enzymeSubstrateBidning.p1, complex.n1) annotation(Line(visible = true, origin = {6.687, 30}, points = {{-2.742, 0}, {-2.742, 0}, {5.484, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ATCase_R.n1, enzymeSubstrateBidning.s1) annotation(Line(visible = true, origin = {-34.625, 40.514}, points = {{-55.375, 11.02}, {4.625, 9.486}, {4.625, -5.514}, {16.07, -5.514}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(Carbamoyl_Aspartate.n1, finalStep.s1) annotation(Line(visible = true, origin = {79.375, 30}, points = {{-9.375, 0}, {9.375, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ATP.n1, conformationEquilibrium.aF1) annotation(Line(visible = true, origin = {-110, 15}, points = {{-10, 0}, {10, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ATCase_T.n1, conformationEquilibrium.s1) annotation(Line(visible = true, origin = {-90, -0.625}, points = {{0, -9.375}, {0, 9.375}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ATCase_R.n1, conformationEquilibrium.p1) annotation(Line(visible = true, origin = {-90, 41.392}, points = {{0, 10.142}, {0, -10.142}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(CTP.n1, conformationEquilibrium.aB1) annotation(Line(visible = true, origin = {-73.333, 20}, points = {{3.333, 0}, {3.333, 0}, {-6.667, 0}}, color = {26, 118, 164}));
  connect(UTP.n1, conformationEquilibrium.iF1) annotation(Line(visible = true, origin = {-115, 25}, points = {{-15, 0}, {15, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(Aspartate.n1, enzymeSubstrateBidning.s2) annotation(Line(visible = true, origin = {-31.778, 30}, points = {{-13.222, 0}, {13.223, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(Carbamoyl_Phosphate.n1, enzymeSubstrateBidning.s3) annotation(Line(visible = true, origin = {-26.185, 20}, points = {{-3.815, -10}, {-3.815, 5}, {7.63, 5}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(finalStep.iF1, CTP.n1) annotation(Line(visible = true, origin = {14.133, 0}, points = {{85.867, 20}, {84.133, -20}, {-84.133, -20}, {-84.133, 20}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(CTP.n1, finalStep.p1) annotation(Line(visible = true, origin = {19.758, 0}, points = {{-89.758, 20}, {-89.758, -25}, {89.758, -25}, {91.492, 30}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  annotation(uses(Modelica(version = "4.0.0"), BioChem(version = "2.0")), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, origin = {3.188, 0}, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-113.188, -113.188}, {113.188, 113.188}}, radius = 25), Text(visible = true, origin = {17.682, 26.428}, textColor = {255, 255, 255}, extent = {{-124.457, -86.428}, {95.173, 35.589}}, textString = "Ex", fontName = "Arial")}), experiment(StopTime = 20, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(ControlPanels(Panel(identifier = "beautiful-fibonacci", title = "Model parameters", elements = {InputField(variable = V, label = "Compartment volume (constant)"), InputField(variable = kCat, label = "Reaction rate for enzyme catalyzed reaction"), InputField(variable = kOff, label = "Reaction rate for reverse enzyme - substrate binding"), InputField(variable = kOn, label = "Reaction rate for forward enzyme - substrate binding")}))), Documentation(info = "<html>
<div style=\"background-color: #f4fbff; padding: 1rem; border: 2px solid #d9e5f3\">
<h2>Library Dependency</h2>
    <p class=\"\">
		This model requires the <a href=\"https://www.wolfram.com/system-modeler/libraries/biochem/\">BioChem</a> library.
	</p>
	<ul>
		<li style=\"background: url('modelica://EducationExamples/Resources/BioChem.png') no-repeat left top; background-size: 32px 32px; padding-left: 40px; \">The free BioChem library is an extendable, general purpose Modelica library for modeling, simulation and visualization of biological and biochemical systems. The library is designed to be used together with Wolfram System Modeler, which enables several extra features such as Systems Biology Markup Language (SBML) import and export. BioChem can, for instance, be used for selecting drug targets with PK/PD modeling or searching for novel drug targets with mechanistic modeling of the reactions in a cell or organism.</li>

	</ul>

</div>

    <h4>Model</h4>
    <p>
This model illustrates the functions of an allosteric enzyme, aspartate carbamoyltransferase (ATCase), and how its activity is affected both by negative feedback regulation and pure modifiers.
</p>
    <p>
The example model consists of the vital substances in the ATCase reaction. Aspartate and carbamoyl phosphate react in an allosterically catalyzed reaction to become carbamoyl aspartate and phosphate. Carbamoyl aspartate is then further transformed into cytidine triphosphate (CTP), in a reaction that in reality consists of several steps that here have been condensed into one. CTP then, together with uridine triphosphate (UTP), inhibits the reaction and decreases the reaction rate by favoring the tense state of ATCase. Adenosine triphosphate (ATP) counters this by instead favoring the relaxed state.
</p>
    <h4>Simulation</h4>
    <p>
Simulating the model allows you to look at how the different substances change over time, and how they are affected by each other. In order to properly analyze this model, it is recommended to use the Wolfram Language notebook that came with this model when it was downloaded. If you prefer to analyze the model in System Modeler, then follow the guide below.
</p>

<p>Simulate the model by clicking the Simulate button: <img src=\"modelica://AllostericControl/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<p>
When the simulation is finished and Simulation Center has been opened, you can analyze the result by clicking the various states to the left of the Simulation Center window and selecting the proper value to analyze, for example, <span>Aspartate.c</span> for changes in aspartate concentration over time or <span>ATCase.der</span> for changes in the derivative of ATCase over time.
</p><p>
To analyze the model based on a different initial parameter set than the default, select the state you want to edit in the Model Center and change the desired initial value under Initialization in the <span>General</span> tab. It can also be done directly from Simulation Center, under the <span>Variables</span> tab.
</p>

<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>
<p>For the full example, open the accompanying notebook <a href=\"AllostericControl.nb\">AllostericControl.nb</a>.</p>


</html>", figures = {Figure(title = "Main reaction concentrations", identifier = "f9b5f", preferred = true, plots = {Plot(curves = {Curve(y = Aspartate.c, legend = "Aspartate"), Curve(y = Carbamoyl_Aspartate.c, legend = "Carbamoyl Aspartate"), Curve(y = CTP.c, legend = "CTP")})}), Figure(title = "Tense relaxed and complex", identifier = "ebdc7", plots = {Plot(curves = {Curve(y = ATCase_T.c, legend = "Tense ATCase"), Curve(y = ATCase_R.c, legend = "Relaxed ATCase"), Curve(y = complex.c, legend = "Enzyme Complex")})}), Figure(title = "Reaction rates", identifier = "0e345", plots = {Plot(curves = {Curve(y = enzymeSubstrateBidning.rr, legend = "Enzyme-Substrate Binding"), Curve(y = enzymeReaction.rr, legend = "Carbamoyl Aspartate Formation"), Curve(y = conformationEquilibrium.rr, legend = "Tense-Relaxed Conformation"), Curve(y = finalStep.rr, legend = "CTP Formation")})}), Figure(title = "Feedback concentrations", identifier = "b1256", plots = {Plot(curves = {Curve(y = ATP.c, legend = "ATP"), Curve(y = CTP.c, legend = "CTP"), Curve(y = UTP.c, legend = "UTP")})})}), Diagram(coordinateSystem(extent = {{-148.5, -40}, {140, 80}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
end AllostericControl;
